@@ -519,7 +519,7 @@ class Flowmeter:
 
         src = self.get_src_ip(df)
         src_df = df.loc[df["src"]==src]
-        return  src_df["time"].diff().sum() 
+        return  src_df['time'].sort_values().diff().sum() 
 
     def get_iat_backward_total_time(self, df):
     
@@ -533,7 +533,7 @@ class Flowmeter:
 
         src = self.get_dst_ip(df)
         src_df = df.loc[df["src"]==src]
-        return  src_df["time"].diff().sum() 
+        return  src_df['time'].sort_values().diff().sum() 
 
     def get_src_times(self, df):
     
@@ -944,7 +944,7 @@ class Flowmeter:
         df (Dataframe): A bi-directional flow pandas dataframe.
         """
         if df.shape[0] > 1:
-            return  min(df["time"].astype(float).diff().dropna())
+            return  min(df['time'].sort_values().astype(float).diff().dropna())
         else:
             return 0
     
@@ -959,7 +959,7 @@ class Flowmeter:
         """
     
         if df.shape[0] > 1:
-            return  max(df["time"].astype(float).diff().dropna())
+            return  max(df['time'].sort_values().astype(float).diff().dropna())
         else:
             return 0
 
@@ -975,7 +975,7 @@ class Flowmeter:
         """
     
         #src_times = get_src_times(df)
-        return df["time"].astype(float).diff().dropna().mean()
+        return df['time'].sort_values().astype(float).diff().dropna().mean()
     
     def get_std_flow_iat(self, df):
     
@@ -987,7 +987,7 @@ class Flowmeter:
         df (Dataframe): A bi-directional flow pandas dataframe.
         """
     
-        return  df["time"].astype(float).diff().dropna().std()
+        return  df['time'].sort_values().astype(float).diff().dropna().std()
 
     def get_total_flow_push_flags(self, df):
     
